@@ -189,8 +189,8 @@ struct spvm_env {
   void* (*get_class_method)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* method_name);
   void* (*get_instance_method_static)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* method_name);
   void* (*get_instance_method)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* method_name);
-  int32_t (*call_method_no_mortal)(SPVM_ENV* env, SPVM_VALUE* stack, void* method, int32_t args_width);
-  int32_t (*call_method)(SPVM_ENV* env, SPVM_VALUE* stack, void* method, int32_t args_width);
+  int32_t (*call_method_no_mortal)(SPVM_ENV* env, SPVM_VALUE* stack, void* method, int32_t args_width, const char* func_name, const char* file, int32_t line);
+  int32_t (*call_method)(SPVM_ENV* env, SPVM_VALUE* stack, void* method, int32_t args_width, const char* func_name, const char* file, int32_t line);
   void (*call_class_method_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* method_name, int32_t args_width, int32_t* error_id, const char* func_name, const char* file, int32_t line);
   void (*call_instance_method_static_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* method_name, int32_t args_width, int32_t* error_id, const char* func_name, const char* file, int32_t line);
   void (*call_instance_method_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* method_name, int32_t args_width, int32_t* error_id, const char* func_name, const char* file, int32_t line);
@@ -331,8 +331,8 @@ struct spvm_env {
   SPVM_VALUE* (*new_stack_with_all_method_call_permitted)(SPVM_ENV* env);
   int32_t (*call_instance_method_no_mortal)(SPVM_ENV* env, SPVM_VALUE* stack, const char* method_name, int32_t args_width);
   int32_t (*call_instance_method)(SPVM_ENV* env, SPVM_VALUE* stack, const char* method_name, int32_t args_width);
-  int32_t (*call_method_no_mortal_no_check_args)(SPVM_ENV* env, SPVM_VALUE* stack, void* method, int32_t args_width);
-  int32_t (*call_instance_method_no_mortal_less_check_args)(SPVM_ENV* env, SPVM_VALUE* stack, const char* method_name, int32_t args_width, const char* decl_args_signature);
+  int32_t (*call_method_no_mortal_no_check_args)(SPVM_ENV* env, SPVM_VALUE* stack, void* method, int32_t args_width, const char* func_name, const char* file_name, int32_t line);
+  int32_t (*call_instance_method_no_mortal_less_check_args)(SPVM_ENV* env, SPVM_VALUE* stack, const char* method_name, int32_t args_width, const char* decl_args_signature, const char* func_name, const char* file_name, int32_t line);
   void (*enable_options)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
   void (*disable_options)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
   int32_t (*is_options)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
@@ -517,6 +517,7 @@ struct spvm_api_method {
   int32_t (*is_not_permitted)(void* runtime, void* method);
   void (*set_is_not_permitted)(void* runtime, void* method, int32_t is_not_permitted);
   const char* (*get_args_signature)(void* runtime, void* method);
+  const char* (*get_abs_name)(void* runtime, void* method);
 };
 
 struct spvm_api_runtime {
@@ -602,6 +603,7 @@ enum {
   SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_METHOD_CALL_NOT_PERMITTED_CLASS,
   SPVM_NATIVE_C_BASIC_TYPE_ID_STRINGABLE_CLASS,
   SPVM_NATIVE_C_BASIC_TYPE_ID_COUNTABLE_CLASS,
+  SPVM_NATIVE_C_BASIC_TYPE_ID_CALLER_INFO_CLASS,
 };
 
 enum {
